## Dataset Attribution
This dataset was created by Pikuliak et al and is licensed under the Apache 2.0 license.

- Original Source: [github.com](https://github.com/kinit-sk/gest/blob/main/data/data_guidelines.pdf)
- License: [https://www.apache.org/licenses/LICENSE-2.0](https://www.apache.org/licenses/LICENSE-2.0)
- Changes Made: The list of stereotypes was extracted.
